@@ -15,12 +15,12 @@ app_key = "867"
 Параметры для callback
 """
 # IP для работы callback`a
-HOST = '85.255.8.26'
+HOST = "85.255.8.26"
 # PORT для работы callback`a
 PORT = 8001
-#данные для подключения к RabbitMQ на callback сервере
-RTMQ_USERNAME = 'hardworker_1'
-RTMQ_PASSWORD = 'password'
-RTMQ_HOST = '85.255.8.26'
+# данные для подключения к RabbitMQ на callback сервере
+RTMQ_USERNAME = "hardworker_1"
+RTMQ_PASSWORD = "password"
+RTMQ_HOST = "85.255.8.26"
 RTMQ_PORT = 5672
-RTMQ_VHOST = 'anticaptcha_vhost'
+RTMQ_VHOST = "anticaptcha_vhost"
